#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CertInfo import CertInfo
from alipay.aop.api.domain.ExchangeRate import ExchangeRate
from alipay.aop.api.domain.AccPayeeInfo import AccPayeeInfo


class AccDetailModel(object):

    def __init__(self):
        self._alipay_order_no = None
        self._cert_info = None
        self._detail_id = None
        self._detail_no = None
        self._error_code = None
        self._error_msg = None
        self._exchange_rate = None
        self._gmt_create = None
        self._gmt_finish = None
        self._need_retry = None
        self._out_biz_no = None
        self._payee_info = None
        self._payment_amount = None
        self._payment_currency = None
        self._remark = None
        self._settlement_amount = None
        self._settlement_currency = None
        self._status = None
        self._sub_status = None
        self._trans_amount = None
        self._trans_currency = None

    @property
    def alipay_order_no(self):
        return self._alipay_order_no

    @alipay_order_no.setter
    def alipay_order_no(self, value):
        self._alipay_order_no = value
    @property
    def cert_info(self):
        return self._cert_info

    @cert_info.setter
    def cert_info(self, value):
        if isinstance(value, CertInfo):
            self._cert_info = value
        else:
            self._cert_info = CertInfo.from_alipay_dict(value)
    @property
    def detail_id(self):
        return self._detail_id

    @detail_id.setter
    def detail_id(self, value):
        self._detail_id = value
    @property
    def detail_no(self):
        return self._detail_no

    @detail_no.setter
    def detail_no(self, value):
        self._detail_no = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def exchange_rate(self):
        return self._exchange_rate

    @exchange_rate.setter
    def exchange_rate(self, value):
        if isinstance(value, ExchangeRate):
            self._exchange_rate = value
        else:
            self._exchange_rate = ExchangeRate.from_alipay_dict(value)
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_finish(self):
        return self._gmt_finish

    @gmt_finish.setter
    def gmt_finish(self, value):
        self._gmt_finish = value
    @property
    def need_retry(self):
        return self._need_retry

    @need_retry.setter
    def need_retry(self, value):
        self._need_retry = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payee_info(self):
        return self._payee_info

    @payee_info.setter
    def payee_info(self, value):
        if isinstance(value, AccPayeeInfo):
            self._payee_info = value
        else:
            self._payee_info = AccPayeeInfo.from_alipay_dict(value)
    @property
    def payment_amount(self):
        return self._payment_amount

    @payment_amount.setter
    def payment_amount(self, value):
        self._payment_amount = value
    @property
    def payment_currency(self):
        return self._payment_currency

    @payment_currency.setter
    def payment_currency(self, value):
        self._payment_currency = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def settlement_amount(self):
        return self._settlement_amount

    @settlement_amount.setter
    def settlement_amount(self, value):
        self._settlement_amount = value
    @property
    def settlement_currency(self):
        return self._settlement_currency

    @settlement_currency.setter
    def settlement_currency(self, value):
        self._settlement_currency = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_status(self):
        return self._sub_status

    @sub_status.setter
    def sub_status(self, value):
        self._sub_status = value
    @property
    def trans_amount(self):
        return self._trans_amount

    @trans_amount.setter
    def trans_amount(self, value):
        self._trans_amount = value
    @property
    def trans_currency(self):
        return self._trans_currency

    @trans_currency.setter
    def trans_currency(self, value):
        self._trans_currency = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_order_no:
            if hasattr(self.alipay_order_no, 'to_alipay_dict'):
                params['alipay_order_no'] = self.alipay_order_no.to_alipay_dict()
            else:
                params['alipay_order_no'] = self.alipay_order_no
        if self.cert_info:
            if hasattr(self.cert_info, 'to_alipay_dict'):
                params['cert_info'] = self.cert_info.to_alipay_dict()
            else:
                params['cert_info'] = self.cert_info
        if self.detail_id:
            if hasattr(self.detail_id, 'to_alipay_dict'):
                params['detail_id'] = self.detail_id.to_alipay_dict()
            else:
                params['detail_id'] = self.detail_id
        if self.detail_no:
            if hasattr(self.detail_no, 'to_alipay_dict'):
                params['detail_no'] = self.detail_no.to_alipay_dict()
            else:
                params['detail_no'] = self.detail_no
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_msg:
            if hasattr(self.error_msg, 'to_alipay_dict'):
                params['error_msg'] = self.error_msg.to_alipay_dict()
            else:
                params['error_msg'] = self.error_msg
        if self.exchange_rate:
            if hasattr(self.exchange_rate, 'to_alipay_dict'):
                params['exchange_rate'] = self.exchange_rate.to_alipay_dict()
            else:
                params['exchange_rate'] = self.exchange_rate
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_finish:
            if hasattr(self.gmt_finish, 'to_alipay_dict'):
                params['gmt_finish'] = self.gmt_finish.to_alipay_dict()
            else:
                params['gmt_finish'] = self.gmt_finish
        if self.need_retry:
            if hasattr(self.need_retry, 'to_alipay_dict'):
                params['need_retry'] = self.need_retry.to_alipay_dict()
            else:
                params['need_retry'] = self.need_retry
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payee_info:
            if hasattr(self.payee_info, 'to_alipay_dict'):
                params['payee_info'] = self.payee_info.to_alipay_dict()
            else:
                params['payee_info'] = self.payee_info
        if self.payment_amount:
            if hasattr(self.payment_amount, 'to_alipay_dict'):
                params['payment_amount'] = self.payment_amount.to_alipay_dict()
            else:
                params['payment_amount'] = self.payment_amount
        if self.payment_currency:
            if hasattr(self.payment_currency, 'to_alipay_dict'):
                params['payment_currency'] = self.payment_currency.to_alipay_dict()
            else:
                params['payment_currency'] = self.payment_currency
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.settlement_amount:
            if hasattr(self.settlement_amount, 'to_alipay_dict'):
                params['settlement_amount'] = self.settlement_amount.to_alipay_dict()
            else:
                params['settlement_amount'] = self.settlement_amount
        if self.settlement_currency:
            if hasattr(self.settlement_currency, 'to_alipay_dict'):
                params['settlement_currency'] = self.settlement_currency.to_alipay_dict()
            else:
                params['settlement_currency'] = self.settlement_currency
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_status:
            if hasattr(self.sub_status, 'to_alipay_dict'):
                params['sub_status'] = self.sub_status.to_alipay_dict()
            else:
                params['sub_status'] = self.sub_status
        if self.trans_amount:
            if hasattr(self.trans_amount, 'to_alipay_dict'):
                params['trans_amount'] = self.trans_amount.to_alipay_dict()
            else:
                params['trans_amount'] = self.trans_amount
        if self.trans_currency:
            if hasattr(self.trans_currency, 'to_alipay_dict'):
                params['trans_currency'] = self.trans_currency.to_alipay_dict()
            else:
                params['trans_currency'] = self.trans_currency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccDetailModel()
        if 'alipay_order_no' in d:
            o.alipay_order_no = d['alipay_order_no']
        if 'cert_info' in d:
            o.cert_info = d['cert_info']
        if 'detail_id' in d:
            o.detail_id = d['detail_id']
        if 'detail_no' in d:
            o.detail_no = d['detail_no']
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_msg' in d:
            o.error_msg = d['error_msg']
        if 'exchange_rate' in d:
            o.exchange_rate = d['exchange_rate']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_finish' in d:
            o.gmt_finish = d['gmt_finish']
        if 'need_retry' in d:
            o.need_retry = d['need_retry']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payee_info' in d:
            o.payee_info = d['payee_info']
        if 'payment_amount' in d:
            o.payment_amount = d['payment_amount']
        if 'payment_currency' in d:
            o.payment_currency = d['payment_currency']
        if 'remark' in d:
            o.remark = d['remark']
        if 'settlement_amount' in d:
            o.settlement_amount = d['settlement_amount']
        if 'settlement_currency' in d:
            o.settlement_currency = d['settlement_currency']
        if 'status' in d:
            o.status = d['status']
        if 'sub_status' in d:
            o.sub_status = d['sub_status']
        if 'trans_amount' in d:
            o.trans_amount = d['trans_amount']
        if 'trans_currency' in d:
            o.trans_currency = d['trans_currency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.WaybillInvoiceIstd import WaybillInvoiceIstd


class AlipayCommerceLogisticsInvoiceIstdwaybillCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceLogisticsInvoiceIstdwaybillCreateResponse, self).__init__()
        self._invoice_fee = None
        self._status = None
        self._waybill_invoices = None

    @property
    def invoice_fee(self):
        return self._invoice_fee

    @invoice_fee.setter
    def invoice_fee(self, value):
        self._invoice_fee = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def waybill_invoices(self):
        return self._waybill_invoices

    @waybill_invoices.setter
    def waybill_invoices(self, value):
        if isinstance(value, list):
            self._waybill_invoices = list()
            for i in value:
                if isinstance(i, WaybillInvoiceIstd):
                    self._waybill_invoices.append(i)
                else:
                    self._waybill_invoices.append(WaybillInvoiceIstd.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceLogisticsInvoiceIstdwaybillCreateResponse, self).parse_response_content(response_content)
        if 'invoice_fee' in response:
            self.invoice_fee = response['invoice_fee']
        if 'status' in response:
            self.status = response['status']
        if 'waybill_invoices' in response:
            self.waybill_invoices = response['waybill_invoices']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SettleClause import SettleClause


class AlipayTradeBatchSettleModel(object):

    def __init__(self):
        self._biz_product = None
        self._extend_params = None
        self._out_request_no = None
        self._settle_clauses = None
        self._settle_type = None

    @property
    def biz_product(self):
        return self._biz_product

    @biz_product.setter
    def biz_product(self, value):
        self._biz_product = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def settle_clauses(self):
        return self._settle_clauses

    @settle_clauses.setter
    def settle_clauses(self, value):
        if isinstance(value, list):
            self._settle_clauses = list()
            for i in value:
                if isinstance(i, SettleClause):
                    self._settle_clauses.append(i)
                else:
                    self._settle_clauses.append(SettleClause.from_alipay_dict(i))
    @property
    def settle_type(self):
        return self._settle_type

    @settle_type.setter
    def settle_type(self, value):
        self._settle_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_product:
            if hasattr(self.biz_product, 'to_alipay_dict'):
                params['biz_product'] = self.biz_product.to_alipay_dict()
            else:
                params['biz_product'] = self.biz_product
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.settle_clauses:
            if isinstance(self.settle_clauses, list):
                for i in range(0, len(self.settle_clauses)):
                    element = self.settle_clauses[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.settle_clauses[i] = element.to_alipay_dict()
            if hasattr(self.settle_clauses, 'to_alipay_dict'):
                params['settle_clauses'] = self.settle_clauses.to_alipay_dict()
            else:
                params['settle_clauses'] = self.settle_clauses
        if self.settle_type:
            if hasattr(self.settle_type, 'to_alipay_dict'):
                params['settle_type'] = self.settle_type.to_alipay_dict()
            else:
                params['settle_type'] = self.settle_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeBatchSettleModel()
        if 'biz_product' in d:
            o.biz_product = d['biz_product']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'settle_clauses' in d:
            o.settle_clauses = d['settle_clauses']
        if 'settle_type' in d:
            o.settle_type = d['settle_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniContentPropertyInfo(object):

    def __init__(self):
        self._key = None
        self._value_list = None

    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value
    @property
    def value_list(self):
        return self._value_list

    @value_list.setter
    def value_list(self, value):
        if isinstance(value, list):
            self._value_list = list()
            for i in value:
                self._value_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        if self.value_list:
            if isinstance(self.value_list, list):
                for i in range(0, len(self.value_list)):
                    element = self.value_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.value_list[i] = element.to_alipay_dict()
            if hasattr(self.value_list, 'to_alipay_dict'):
                params['value_list'] = self.value_list.to_alipay_dict()
            else:
                params['value_list'] = self.value_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniContentPropertyInfo()
        if 'key' in d:
            o.key = d['key']
        if 'value_list' in d:
            o.value_list = d['value_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FulfillmentInfo(object):

    def __init__(self):
        self._biz_ext_param = None
        self._biz_time = None
        self._out_order_no = None

    @property
    def biz_ext_param(self):
        return self._biz_ext_param

    @biz_ext_param.setter
    def biz_ext_param(self, value):
        self._biz_ext_param = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_ext_param:
            if hasattr(self.biz_ext_param, 'to_alipay_dict'):
                params['biz_ext_param'] = self.biz_ext_param.to_alipay_dict()
            else:
                params['biz_ext_param'] = self.biz_ext_param
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FulfillmentInfo()
        if 'biz_ext_param' in d:
            o.biz_ext_param = d['biz_ext_param']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Member import Member


class MybankCreditSupplychainTradePayableQueryModel(object):

    def __init__(self):
        self._buyer = None
        self._out_order_no = None
        self._sale_pd_code = None
        self._trade_type = None

    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, Member):
            self._buyer = value
        else:
            self._buyer = Member.from_alipay_dict(value)
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def sale_pd_code(self):
        return self._sale_pd_code

    @sale_pd_code.setter
    def sale_pd_code(self, value):
        self._sale_pd_code = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer:
            if hasattr(self.buyer, 'to_alipay_dict'):
                params['buyer'] = self.buyer.to_alipay_dict()
            else:
                params['buyer'] = self.buyer
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.sale_pd_code:
            if hasattr(self.sale_pd_code, 'to_alipay_dict'):
                params['sale_pd_code'] = self.sale_pd_code.to_alipay_dict()
            else:
                params['sale_pd_code'] = self.sale_pd_code
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainTradePayableQueryModel()
        if 'buyer' in d:
            o.buyer = d['buyer']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'sale_pd_code' in d:
            o.sale_pd_code = d['sale_pd_code']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ReceiptSimpleOrderDTO import ReceiptSimpleOrderDTO


class AlipayCommerceReceiptSyncModel(object):

    def __init__(self):
        self._order_list = None

    @property
    def order_list(self):
        return self._order_list

    @order_list.setter
    def order_list(self, value):
        if isinstance(value, list):
            self._order_list = list()
            for i in value:
                if isinstance(i, ReceiptSimpleOrderDTO):
                    self._order_list.append(i)
                else:
                    self._order_list.append(ReceiptSimpleOrderDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.order_list:
            if isinstance(self.order_list, list):
                for i in range(0, len(self.order_list)):
                    element = self.order_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_list[i] = element.to_alipay_dict()
            if hasattr(self.order_list, 'to_alipay_dict'):
                params['order_list'] = self.order_list.to_alipay_dict()
            else:
                params['order_list'] = self.order_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceReceiptSyncModel()
        if 'order_list' in d:
            o.order_list = d['order_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoney import MultiCurrencyMoney


class StandardVoucherMultipleConditionQueryRequest(object):

    def __init__(self):
        self._account_alias_name = None
        self._account_no_list = None
        self._algorithm_tag = None
        self._black_trans_account_no_list = None
        self._black_trans_inst_id_list = None
        self._cur_page = None
        self._env = None
        self._fund_biz_code_list = None
        self._handle_status_list = None
        self._inst_serial_no = None
        self._manual_dist_memo = None
        self._manual_dist_type_list = None
        self._memo = None
        self._org_trans_no = None
        self._other_account_alias_name = None
        self._other_account_name = None
        self._other_account_no = None
        self._page_size = None
        self._query_source = None
        self._sort_type = None
        self._status_list = None
        self._tnt_inst_id = None
        self._trans_amount = None
        self._trans_currency = None
        self._trans_direction_list = None
        self._trans_end = None
        self._trans_inst_id_list = None
        self._trans_start = None
        self._voucher_type = None

    @property
    def account_alias_name(self):
        return self._account_alias_name

    @account_alias_name.setter
    def account_alias_name(self, value):
        self._account_alias_name = value
    @property
    def account_no_list(self):
        return self._account_no_list

    @account_no_list.setter
    def account_no_list(self, value):
        if isinstance(value, list):
            self._account_no_list = list()
            for i in value:
                self._account_no_list.append(i)
    @property
    def algorithm_tag(self):
        return self._algorithm_tag

    @algorithm_tag.setter
    def algorithm_tag(self, value):
        self._algorithm_tag = value
    @property
    def black_trans_account_no_list(self):
        return self._black_trans_account_no_list

    @black_trans_account_no_list.setter
    def black_trans_account_no_list(self, value):
        if isinstance(value, list):
            self._black_trans_account_no_list = list()
            for i in value:
                self._black_trans_account_no_list.append(i)
    @property
    def black_trans_inst_id_list(self):
        return self._black_trans_inst_id_list

    @black_trans_inst_id_list.setter
    def black_trans_inst_id_list(self, value):
        if isinstance(value, list):
            self._black_trans_inst_id_list = list()
            for i in value:
                self._black_trans_inst_id_list.append(i)
    @property
    def cur_page(self):
        return self._cur_page

    @cur_page.setter
    def cur_page(self, value):
        self._cur_page = value
    @property
    def env(self):
        return self._env

    @env.setter
    def env(self, value):
        self._env = value
    @property
    def fund_biz_code_list(self):
        return self._fund_biz_code_list

    @fund_biz_code_list.setter
    def fund_biz_code_list(self, value):
        if isinstance(value, list):
            self._fund_biz_code_list = list()
            for i in value:
                self._fund_biz_code_list.append(i)
    @property
    def handle_status_list(self):
        return self._handle_status_list

    @handle_status_list.setter
    def handle_status_list(self, value):
        if isinstance(value, list):
            self._handle_status_list = list()
            for i in value:
                self._handle_status_list.append(i)
    @property
    def inst_serial_no(self):
        return self._inst_serial_no

    @inst_serial_no.setter
    def inst_serial_no(self, value):
        self._inst_serial_no = value
    @property
    def manual_dist_memo(self):
        return self._manual_dist_memo

    @manual_dist_memo.setter
    def manual_dist_memo(self, value):
        self._manual_dist_memo = value
    @property
    def manual_dist_type_list(self):
        return self._manual_dist_type_list

    @manual_dist_type_list.setter
    def manual_dist_type_list(self, value):
        if isinstance(value, list):
            self._manual_dist_type_list = list()
            for i in value:
                self._manual_dist_type_list.append(i)
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def org_trans_no(self):
        return self._org_trans_no

    @org_trans_no.setter
    def org_trans_no(self, value):
        self._org_trans_no = value
    @property
    def other_account_alias_name(self):
        return self._other_account_alias_name

    @other_account_alias_name.setter
    def other_account_alias_name(self, value):
        self._other_account_alias_name = value
    @property
    def other_account_name(self):
        return self._other_account_name

    @other_account_name.setter
    def other_account_name(self, value):
        self._other_account_name = value
    @property
    def other_account_no(self):
        return self._other_account_no

    @other_account_no.setter
    def other_account_no(self, value):
        self._other_account_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def query_source(self):
        return self._query_source

    @query_source.setter
    def query_source(self, value):
        self._query_source = value
    @property
    def sort_type(self):
        return self._sort_type

    @sort_type.setter
    def sort_type(self, value):
        self._sort_type = value
    @property
    def status_list(self):
        return self._status_list

    @status_list.setter
    def status_list(self, value):
        if isinstance(value, list):
            self._status_list = list()
            for i in value:
                self._status_list.append(i)
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def trans_amount(self):
        return self._trans_amount

    @trans_amount.setter
    def trans_amount(self, value):
        if isinstance(value, MultiCurrencyMoney):
            self._trans_amount = value
        else:
            self._trans_amount = MultiCurrencyMoney.from_alipay_dict(value)
    @property
    def trans_currency(self):
        return self._trans_currency

    @trans_currency.setter
    def trans_currency(self, value):
        self._trans_currency = value
    @property
    def trans_direction_list(self):
        return self._trans_direction_list

    @trans_direction_list.setter
    def trans_direction_list(self, value):
        if isinstance(value, list):
            self._trans_direction_list = list()
            for i in value:
                self._trans_direction_list.append(i)
    @property
    def trans_end(self):
        return self._trans_end

    @trans_end.setter
    def trans_end(self, value):
        self._trans_end = value
    @property
    def trans_inst_id_list(self):
        return self._trans_inst_id_list

    @trans_inst_id_list.setter
    def trans_inst_id_list(self, value):
        if isinstance(value, list):
            self._trans_inst_id_list = list()
            for i in value:
                self._trans_inst_id_list.append(i)
    @property
    def trans_start(self):
        return self._trans_start

    @trans_start.setter
    def trans_start(self, value):
        self._trans_start = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_alias_name:
            if hasattr(self.account_alias_name, 'to_alipay_dict'):
                params['account_alias_name'] = self.account_alias_name.to_alipay_dict()
            else:
                params['account_alias_name'] = self.account_alias_name
        if self.account_no_list:
            if isinstance(self.account_no_list, list):
                for i in range(0, len(self.account_no_list)):
                    element = self.account_no_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.account_no_list[i] = element.to_alipay_dict()
            if hasattr(self.account_no_list, 'to_alipay_dict'):
                params['account_no_list'] = self.account_no_list.to_alipay_dict()
            else:
                params['account_no_list'] = self.account_no_list
        if self.algorithm_tag:
            if hasattr(self.algorithm_tag, 'to_alipay_dict'):
                params['algorithm_tag'] = self.algorithm_tag.to_alipay_dict()
            else:
                params['algorithm_tag'] = self.algorithm_tag
        if self.black_trans_account_no_list:
            if isinstance(self.black_trans_account_no_list, list):
                for i in range(0, len(self.black_trans_account_no_list)):
                    element = self.black_trans_account_no_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.black_trans_account_no_list[i] = element.to_alipay_dict()
            if hasattr(self.black_trans_account_no_list, 'to_alipay_dict'):
                params['black_trans_account_no_list'] = self.black_trans_account_no_list.to_alipay_dict()
            else:
                params['black_trans_account_no_list'] = self.black_trans_account_no_list
        if self.black_trans_inst_id_list:
            if isinstance(self.black_trans_inst_id_list, list):
                for i in range(0, len(self.black_trans_inst_id_list)):
                    element = self.black_trans_inst_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.black_trans_inst_id_list[i] = element.to_alipay_dict()
            if hasattr(self.black_trans_inst_id_list, 'to_alipay_dict'):
                params['black_trans_inst_id_list'] = self.black_trans_inst_id_list.to_alipay_dict()
            else:
                params['black_trans_inst_id_list'] = self.black_trans_inst_id_list
        if self.cur_page:
            if hasattr(self.cur_page, 'to_alipay_dict'):
                params['cur_page'] = self.cur_page.to_alipay_dict()
            else:
                params['cur_page'] = self.cur_page
        if self.env:
            if hasattr(self.env, 'to_alipay_dict'):
                params['env'] = self.env.to_alipay_dict()
            else:
                params['env'] = self.env
        if self.fund_biz_code_list:
            if isinstance(self.fund_biz_code_list, list):
                for i in range(0, len(self.fund_biz_code_list)):
                    element = self.fund_biz_code_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.fund_biz_code_list[i] = element.to_alipay_dict()
            if hasattr(self.fund_biz_code_list, 'to_alipay_dict'):
                params['fund_biz_code_list'] = self.fund_biz_code_list.to_alipay_dict()
            else:
                params['fund_biz_code_list'] = self.fund_biz_code_list
        if self.handle_status_list:
            if isinstance(self.handle_status_list, list):
                for i in range(0, len(self.handle_status_list)):
                    element = self.handle_status_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.handle_status_list[i] = element.to_alipay_dict()
            if hasattr(self.handle_status_list, 'to_alipay_dict'):
                params['handle_status_list'] = self.handle_status_list.to_alipay_dict()
            else:
                params['handle_status_list'] = self.handle_status_list
        if self.inst_serial_no:
            if hasattr(self.inst_serial_no, 'to_alipay_dict'):
                params['inst_serial_no'] = self.inst_serial_no.to_alipay_dict()
            else:
                params['inst_serial_no'] = self.inst_serial_no
        if self.manual_dist_memo:
            if hasattr(self.manual_dist_memo, 'to_alipay_dict'):
                params['manual_dist_memo'] = self.manual_dist_memo.to_alipay_dict()
            else:
                params['manual_dist_memo'] = self.manual_dist_memo
        if self.manual_dist_type_list:
            if isinstance(self.manual_dist_type_list, list):
                for i in range(0, len(self.manual_dist_type_list)):
                    element = self.manual_dist_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.manual_dist_type_list[i] = element.to_alipay_dict()
            if hasattr(self.manual_dist_type_list, 'to_alipay_dict'):
                params['manual_dist_type_list'] = self.manual_dist_type_list.to_alipay_dict()
            else:
                params['manual_dist_type_list'] = self.manual_dist_type_list
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.org_trans_no:
            if hasattr(self.org_trans_no, 'to_alipay_dict'):
                params['org_trans_no'] = self.org_trans_no.to_alipay_dict()
            else:
                params['org_trans_no'] = self.org_trans_no
        if self.other_account_alias_name:
            if hasattr(self.other_account_alias_name, 'to_alipay_dict'):
                params['other_account_alias_name'] = self.other_account_alias_name.to_alipay_dict()
            else:
                params['other_account_alias_name'] = self.other_account_alias_name
        if self.other_account_name:
            if hasattr(self.other_account_name, 'to_alipay_dict'):
                params['other_account_name'] = self.other_account_name.to_alipay_dict()
            else:
                params['other_account_name'] = self.other_account_name
        if self.other_account_no:
            if hasattr(self.other_account_no, 'to_alipay_dict'):
                params['other_account_no'] = self.other_account_no.to_alipay_dict()
            else:
                params['other_account_no'] = self.other_account_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.query_source:
            if hasattr(self.query_source, 'to_alipay_dict'):
                params['query_source'] = self.query_source.to_alipay_dict()
            else:
                params['query_source'] = self.query_source
        if self.sort_type:
            if hasattr(self.sort_type, 'to_alipay_dict'):
                params['sort_type'] = self.sort_type.to_alipay_dict()
            else:
                params['sort_type'] = self.sort_type
        if self.status_list:
            if isinstance(self.status_list, list):
                for i in range(0, len(self.status_list)):
                    element = self.status_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.status_list[i] = element.to_alipay_dict()
            if hasattr(self.status_list, 'to_alipay_dict'):
                params['status_list'] = self.status_list.to_alipay_dict()
            else:
                params['status_list'] = self.status_list
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.trans_amount:
            if hasattr(self.trans_amount, 'to_alipay_dict'):
                params['trans_amount'] = self.trans_amount.to_alipay_dict()
            else:
                params['trans_amount'] = self.trans_amount
        if self.trans_currency:
            if hasattr(self.trans_currency, 'to_alipay_dict'):
                params['trans_currency'] = self.trans_currency.to_alipay_dict()
            else:
                params['trans_currency'] = self.trans_currency
        if self.trans_direction_list:
            if isinstance(self.trans_direction_list, list):
                for i in range(0, len(self.trans_direction_list)):
                    element = self.trans_direction_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.trans_direction_list[i] = element.to_alipay_dict()
            if hasattr(self.trans_direction_list, 'to_alipay_dict'):
                params['trans_direction_list'] = self.trans_direction_list.to_alipay_dict()
            else:
                params['trans_direction_list'] = self.trans_direction_list
        if self.trans_end:
            if hasattr(self.trans_end, 'to_alipay_dict'):
                params['trans_end'] = self.trans_end.to_alipay_dict()
            else:
                params['trans_end'] = self.trans_end
        if self.trans_inst_id_list:
            if isinstance(self.trans_inst_id_list, list):
                for i in range(0, len(self.trans_inst_id_list)):
                    element = self.trans_inst_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.trans_inst_id_list[i] = element.to_alipay_dict()
            if hasattr(self.trans_inst_id_list, 'to_alipay_dict'):
                params['trans_inst_id_list'] = self.trans_inst_id_list.to_alipay_dict()
            else:
                params['trans_inst_id_list'] = self.trans_inst_id_list
        if self.trans_start:
            if hasattr(self.trans_start, 'to_alipay_dict'):
                params['trans_start'] = self.trans_start.to_alipay_dict()
            else:
                params['trans_start'] = self.trans_start
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StandardVoucherMultipleConditionQueryRequest()
        if 'account_alias_name' in d:
            o.account_alias_name = d['account_alias_name']
        if 'account_no_list' in d:
            o.account_no_list = d['account_no_list']
        if 'algorithm_tag' in d:
            o.algorithm_tag = d['algorithm_tag']
        if 'black_trans_account_no_list' in d:
            o.black_trans_account_no_list = d['black_trans_account_no_list']
        if 'black_trans_inst_id_list' in d:
            o.black_trans_inst_id_list = d['black_trans_inst_id_list']
        if 'cur_page' in d:
            o.cur_page = d['cur_page']
        if 'env' in d:
            o.env = d['env']
        if 'fund_biz_code_list' in d:
            o.fund_biz_code_list = d['fund_biz_code_list']
        if 'handle_status_list' in d:
            o.handle_status_list = d['handle_status_list']
        if 'inst_serial_no' in d:
            o.inst_serial_no = d['inst_serial_no']
        if 'manual_dist_memo' in d:
            o.manual_dist_memo = d['manual_dist_memo']
        if 'manual_dist_type_list' in d:
            o.manual_dist_type_list = d['manual_dist_type_list']
        if 'memo' in d:
            o.memo = d['memo']
        if 'org_trans_no' in d:
            o.org_trans_no = d['org_trans_no']
        if 'other_account_alias_name' in d:
            o.other_account_alias_name = d['other_account_alias_name']
        if 'other_account_name' in d:
            o.other_account_name = d['other_account_name']
        if 'other_account_no' in d:
            o.other_account_no = d['other_account_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'query_source' in d:
            o.query_source = d['query_source']
        if 'sort_type' in d:
            o.sort_type = d['sort_type']
        if 'status_list' in d:
            o.status_list = d['status_list']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'trans_amount' in d:
            o.trans_amount = d['trans_amount']
        if 'trans_currency' in d:
            o.trans_currency = d['trans_currency']
        if 'trans_direction_list' in d:
            o.trans_direction_list = d['trans_direction_list']
        if 'trans_end' in d:
            o.trans_end = d['trans_end']
        if 'trans_inst_id_list' in d:
            o.trans_inst_id_list = d['trans_inst_id_list']
        if 'trans_start' in d:
            o.trans_start = d['trans_start']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RepayDetail(object):

    def __init__(self):
        self._capital_amount = None
        self._contract_no = None
        self._interest_amount = None
        self._loan_year = None
        self._total_amount = None

    @property
    def capital_amount(self):
        return self._capital_amount

    @capital_amount.setter
    def capital_amount(self, value):
        self._capital_amount = value
    @property
    def contract_no(self):
        return self._contract_no

    @contract_no.setter
    def contract_no(self, value):
        self._contract_no = value
    @property
    def interest_amount(self):
        return self._interest_amount

    @interest_amount.setter
    def interest_amount(self, value):
        self._interest_amount = value
    @property
    def loan_year(self):
        return self._loan_year

    @loan_year.setter
    def loan_year(self, value):
        self._loan_year = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.capital_amount:
            if hasattr(self.capital_amount, 'to_alipay_dict'):
                params['capital_amount'] = self.capital_amount.to_alipay_dict()
            else:
                params['capital_amount'] = self.capital_amount
        if self.contract_no:
            if hasattr(self.contract_no, 'to_alipay_dict'):
                params['contract_no'] = self.contract_no.to_alipay_dict()
            else:
                params['contract_no'] = self.contract_no
        if self.interest_amount:
            if hasattr(self.interest_amount, 'to_alipay_dict'):
                params['interest_amount'] = self.interest_amount.to_alipay_dict()
            else:
                params['interest_amount'] = self.interest_amount
        if self.loan_year:
            if hasattr(self.loan_year, 'to_alipay_dict'):
                params['loan_year'] = self.loan_year.to_alipay_dict()
            else:
                params['loan_year'] = self.loan_year
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RepayDetail()
        if 'capital_amount' in d:
            o.capital_amount = d['capital_amount']
        if 'contract_no' in d:
            o.contract_no = d['contract_no']
        if 'interest_amount' in d:
            o.interest_amount = d['interest_amount']
        if 'loan_year' in d:
            o.loan_year = d['loan_year']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotDeviceAudioSyncModel(object):

    def __init__(self):
        self._biz_tid = None
        self._trade_id = None
        self._trade_type = None
        self._voice_content = None

    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def trade_id(self):
        return self._trade_id

    @trade_id.setter
    def trade_id(self, value):
        self._trade_id = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value
    @property
    def voice_content(self):
        return self._voice_content

    @voice_content.setter
    def voice_content(self, value):
        self._voice_content = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.trade_id:
            if hasattr(self.trade_id, 'to_alipay_dict'):
                params['trade_id'] = self.trade_id.to_alipay_dict()
            else:
                params['trade_id'] = self.trade_id
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        if self.voice_content:
            if hasattr(self.voice_content, 'to_alipay_dict'):
                params['voice_content'] = self.voice_content.to_alipay_dict()
            else:
                params['voice_content'] = self.voice_content
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotDeviceAudioSyncModel()
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'trade_id' in d:
            o.trade_id = d['trade_id']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        if 'voice_content' in d:
            o.voice_content = d['voice_content']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QueryInfo(object):

    def __init__(self):
        self._app_name = None
        self._operator = None
        self._query_type = None
        self._user_no = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def query_type(self):
        return self._query_type

    @query_type.setter
    def query_type(self, value):
        self._query_type = value
    @property
    def user_no(self):
        return self._user_no

    @user_no.setter
    def user_no(self, value):
        self._user_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.query_type:
            if hasattr(self.query_type, 'to_alipay_dict'):
                params['query_type'] = self.query_type.to_alipay_dict()
            else:
                params['query_type'] = self.query_type
        if self.user_no:
            if hasattr(self.user_no, 'to_alipay_dict'):
                params['user_no'] = self.user_no.to_alipay_dict()
            else:
                params['user_no'] = self.user_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueryInfo()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'operator' in d:
            o.operator = d['operator']
        if 'query_type' in d:
            o.query_type = d['query_type']
        if 'user_no' in d:
            o.user_no = d['user_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SettleCardInfo import SettleCardInfo
from alipay.aop.api.domain.DefaultSettleRule import DefaultSettleRule


class AntMerchantExpandIndirectZftSettlementmodifyModel(object):

    def __init__(self):
        self._alipay_logon_id = None
        self._biz_cards = None
        self._default_settle_rule = None
        self._license_auth_letter_image = None
        self._smid = None

    @property
    def alipay_logon_id(self):
        return self._alipay_logon_id

    @alipay_logon_id.setter
    def alipay_logon_id(self, value):
        self._alipay_logon_id = value
    @property
    def biz_cards(self):
        return self._biz_cards

    @biz_cards.setter
    def biz_cards(self, value):
        if isinstance(value, SettleCardInfo):
            self._biz_cards = value
        else:
            self._biz_cards = SettleCardInfo.from_alipay_dict(value)
    @property
    def default_settle_rule(self):
        return self._default_settle_rule

    @default_settle_rule.setter
    def default_settle_rule(self, value):
        if isinstance(value, DefaultSettleRule):
            self._default_settle_rule = value
        else:
            self._default_settle_rule = DefaultSettleRule.from_alipay_dict(value)
    @property
    def license_auth_letter_image(self):
        return self._license_auth_letter_image

    @license_auth_letter_image.setter
    def license_auth_letter_image(self, value):
        self._license_auth_letter_image = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_logon_id:
            if hasattr(self.alipay_logon_id, 'to_alipay_dict'):
                params['alipay_logon_id'] = self.alipay_logon_id.to_alipay_dict()
            else:
                params['alipay_logon_id'] = self.alipay_logon_id
        if self.biz_cards:
            if hasattr(self.biz_cards, 'to_alipay_dict'):
                params['biz_cards'] = self.biz_cards.to_alipay_dict()
            else:
                params['biz_cards'] = self.biz_cards
        if self.default_settle_rule:
            if hasattr(self.default_settle_rule, 'to_alipay_dict'):
                params['default_settle_rule'] = self.default_settle_rule.to_alipay_dict()
            else:
                params['default_settle_rule'] = self.default_settle_rule
        if self.license_auth_letter_image:
            if hasattr(self.license_auth_letter_image, 'to_alipay_dict'):
                params['license_auth_letter_image'] = self.license_auth_letter_image.to_alipay_dict()
            else:
                params['license_auth_letter_image'] = self.license_auth_letter_image
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIndirectZftSettlementmodifyModel()
        if 'alipay_logon_id' in d:
            o.alipay_logon_id = d['alipay_logon_id']
        if 'biz_cards' in d:
            o.biz_cards = d['biz_cards']
        if 'default_settle_rule' in d:
            o.default_settle_rule = d['default_settle_rule']
        if 'license_auth_letter_image' in d:
            o.license_auth_letter_image = d['license_auth_letter_image']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OverseasTravelRate(object):

    def __init__(self):
        self._currency = None
        self._currency_icon = None
        self._rate = None

    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def currency_icon(self):
        return self._currency_icon

    @currency_icon.setter
    def currency_icon(self, value):
        self._currency_icon = value
    @property
    def rate(self):
        return self._rate

    @rate.setter
    def rate(self, value):
        self._rate = value


    def to_alipay_dict(self):
        params = dict()
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.currency_icon:
            if hasattr(self.currency_icon, 'to_alipay_dict'):
                params['currency_icon'] = self.currency_icon.to_alipay_dict()
            else:
                params['currency_icon'] = self.currency_icon
        if self.rate:
            if hasattr(self.rate, 'to_alipay_dict'):
                params['rate'] = self.rate.to_alipay_dict()
            else:
                params['rate'] = self.rate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OverseasTravelRate()
        if 'currency' in d:
            o.currency = d['currency']
        if 'currency_icon' in d:
            o.currency_icon = d['currency_icon']
        if 'rate' in d:
            o.rate = d['rate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PointInstruction(object):

    def __init__(self):
        self._action_type = None
        self._point_amount = None
        self._reason = None
        self._status = None
        self._task_name = None
        self._time = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def point_amount(self):
        return self._point_amount

    @point_amount.setter
    def point_amount(self, value):
        self._point_amount = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def task_name(self):
        return self._task_name

    @task_name.setter
    def task_name(self, value):
        self._task_name = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.point_amount:
            if hasattr(self.point_amount, 'to_alipay_dict'):
                params['point_amount'] = self.point_amount.to_alipay_dict()
            else:
                params['point_amount'] = self.point_amount
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.task_name:
            if hasattr(self.task_name, 'to_alipay_dict'):
                params['task_name'] = self.task_name.to_alipay_dict()
            else:
                params['task_name'] = self.task_name
        if self.time:
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PointInstruction()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'point_amount' in d:
            o.point_amount = d['point_amount']
        if 'reason' in d:
            o.reason = d['reason']
        if 'status' in d:
            o.status = d['status']
        if 'task_name' in d:
            o.task_name = d['task_name']
        if 'time' in d:
            o.time = d['time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ScenicAuditResponse import ScenicAuditResponse


class AlipayCommerceDataScenicMappingQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceDataScenicMappingQueryResponse, self).__init__()
        self._scenic_audit_response = None

    @property
    def scenic_audit_response(self):
        return self._scenic_audit_response

    @scenic_audit_response.setter
    def scenic_audit_response(self, value):
        if isinstance(value, ScenicAuditResponse):
            self._scenic_audit_response = value
        else:
            self._scenic_audit_response = ScenicAuditResponse.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceDataScenicMappingQueryResponse, self).parse_response_content(response_content)
        if 'scenic_audit_response' in response:
            self.scenic_audit_response = response['scenic_audit_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherRec import VoucherRec


class ShopRec(object):

    def __init__(self):
        self._address = None
        self._brand_name = None
        self._busi_area = None
        self._city_id = None
        self._cuisine = None
        self._distance = None
        self._ext_info = None
        self._has_hui = None
        self._head_shop_name = None
        self._latitude = None
        self._longitude = None
        self._popularity = None
        self._popularity_level = None
        self._price_average = None
        self._root_display_category_info = None
        self._shop_detail_url = None
        self._shop_id = None
        self._shop_logo_url = None
        self._shop_name = None
        self._shop_recommend_one_tag_compose = None
        self._voucher_list = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def busi_area(self):
        return self._busi_area

    @busi_area.setter
    def busi_area(self, value):
        self._busi_area = value
    @property
    def city_id(self):
        return self._city_id

    @city_id.setter
    def city_id(self, value):
        self._city_id = value
    @property
    def cuisine(self):
        return self._cuisine

    @cuisine.setter
    def cuisine(self, value):
        self._cuisine = value
    @property
    def distance(self):
        return self._distance

    @distance.setter
    def distance(self, value):
        self._distance = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def has_hui(self):
        return self._has_hui

    @has_hui.setter
    def has_hui(self, value):
        self._has_hui = value
    @property
    def head_shop_name(self):
        return self._head_shop_name

    @head_shop_name.setter
    def head_shop_name(self, value):
        self._head_shop_name = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def popularity(self):
        return self._popularity

    @popularity.setter
    def popularity(self, value):
        self._popularity = value
    @property
    def popularity_level(self):
        return self._popularity_level

    @popularity_level.setter
    def popularity_level(self, value):
        self._popularity_level = value
    @property
    def price_average(self):
        return self._price_average

    @price_average.setter
    def price_average(self, value):
        self._price_average = value
    @property
    def root_display_category_info(self):
        return self._root_display_category_info

    @root_display_category_info.setter
    def root_display_category_info(self, value):
        self._root_display_category_info = value
    @property
    def shop_detail_url(self):
        return self._shop_detail_url

    @shop_detail_url.setter
    def shop_detail_url(self, value):
        self._shop_detail_url = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_logo_url(self):
        return self._shop_logo_url

    @shop_logo_url.setter
    def shop_logo_url(self, value):
        self._shop_logo_url = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_recommend_one_tag_compose(self):
        return self._shop_recommend_one_tag_compose

    @shop_recommend_one_tag_compose.setter
    def shop_recommend_one_tag_compose(self, value):
        self._shop_recommend_one_tag_compose = value
    @property
    def voucher_list(self):
        return self._voucher_list

    @voucher_list.setter
    def voucher_list(self, value):
        if isinstance(value, list):
            self._voucher_list = list()
            for i in value:
                if isinstance(i, VoucherRec):
                    self._voucher_list.append(i)
                else:
                    self._voucher_list.append(VoucherRec.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.busi_area:
            if hasattr(self.busi_area, 'to_alipay_dict'):
                params['busi_area'] = self.busi_area.to_alipay_dict()
            else:
                params['busi_area'] = self.busi_area
        if self.city_id:
            if hasattr(self.city_id, 'to_alipay_dict'):
                params['city_id'] = self.city_id.to_alipay_dict()
            else:
                params['city_id'] = self.city_id
        if self.cuisine:
            if hasattr(self.cuisine, 'to_alipay_dict'):
                params['cuisine'] = self.cuisine.to_alipay_dict()
            else:
                params['cuisine'] = self.cuisine
        if self.distance:
            if hasattr(self.distance, 'to_alipay_dict'):
                params['distance'] = self.distance.to_alipay_dict()
            else:
                params['distance'] = self.distance
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.has_hui:
            if hasattr(self.has_hui, 'to_alipay_dict'):
                params['has_hui'] = self.has_hui.to_alipay_dict()
            else:
                params['has_hui'] = self.has_hui
        if self.head_shop_name:
            if hasattr(self.head_shop_name, 'to_alipay_dict'):
                params['head_shop_name'] = self.head_shop_name.to_alipay_dict()
            else:
                params['head_shop_name'] = self.head_shop_name
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.popularity:
            if hasattr(self.popularity, 'to_alipay_dict'):
                params['popularity'] = self.popularity.to_alipay_dict()
            else:
                params['popularity'] = self.popularity
        if self.popularity_level:
            if hasattr(self.popularity_level, 'to_alipay_dict'):
                params['popularity_level'] = self.popularity_level.to_alipay_dict()
            else:
                params['popularity_level'] = self.popularity_level
        if self.price_average:
            if hasattr(self.price_average, 'to_alipay_dict'):
                params['price_average'] = self.price_average.to_alipay_dict()
            else:
                params['price_average'] = self.price_average
        if self.root_display_category_info:
            if hasattr(self.root_display_category_info, 'to_alipay_dict'):
                params['root_display_category_info'] = self.root_display_category_info.to_alipay_dict()
            else:
                params['root_display_category_info'] = self.root_display_category_info
        if self.shop_detail_url:
            if hasattr(self.shop_detail_url, 'to_alipay_dict'):
                params['shop_detail_url'] = self.shop_detail_url.to_alipay_dict()
            else:
                params['shop_detail_url'] = self.shop_detail_url
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_logo_url:
            if hasattr(self.shop_logo_url, 'to_alipay_dict'):
                params['shop_logo_url'] = self.shop_logo_url.to_alipay_dict()
            else:
                params['shop_logo_url'] = self.shop_logo_url
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_recommend_one_tag_compose:
            if hasattr(self.shop_recommend_one_tag_compose, 'to_alipay_dict'):
                params['shop_recommend_one_tag_compose'] = self.shop_recommend_one_tag_compose.to_alipay_dict()
            else:
                params['shop_recommend_one_tag_compose'] = self.shop_recommend_one_tag_compose
        if self.voucher_list:
            if isinstance(self.voucher_list, list):
                for i in range(0, len(self.voucher_list)):
                    element = self.voucher_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.voucher_list[i] = element.to_alipay_dict()
            if hasattr(self.voucher_list, 'to_alipay_dict'):
                params['voucher_list'] = self.voucher_list.to_alipay_dict()
            else:
                params['voucher_list'] = self.voucher_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopRec()
        if 'address' in d:
            o.address = d['address']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'busi_area' in d:
            o.busi_area = d['busi_area']
        if 'city_id' in d:
            o.city_id = d['city_id']
        if 'cuisine' in d:
            o.cuisine = d['cuisine']
        if 'distance' in d:
            o.distance = d['distance']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'has_hui' in d:
            o.has_hui = d['has_hui']
        if 'head_shop_name' in d:
            o.head_shop_name = d['head_shop_name']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'popularity' in d:
            o.popularity = d['popularity']
        if 'popularity_level' in d:
            o.popularity_level = d['popularity_level']
        if 'price_average' in d:
            o.price_average = d['price_average']
        if 'root_display_category_info' in d:
            o.root_display_category_info = d['root_display_category_info']
        if 'shop_detail_url' in d:
            o.shop_detail_url = d['shop_detail_url']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_logo_url' in d:
            o.shop_logo_url = d['shop_logo_url']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_recommend_one_tag_compose' in d:
            o.shop_recommend_one_tag_compose = d['shop_recommend_one_tag_compose']
        if 'voucher_list' in d:
            o.voucher_list = d['voucher_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoantradeRepayBudgetQueryModel(object):

    def __init__(self):
        self._apply_repay_prin = None
        self._budget_type = None
        self._can_repay_flag = None
        self._ext_data = None
        self._ip_id = None
        self._ip_role_id = None
        self._loan_ar_no = None
        self._repay_scene = None

    @property
    def apply_repay_prin(self):
        return self._apply_repay_prin

    @apply_repay_prin.setter
    def apply_repay_prin(self, value):
        self._apply_repay_prin = value
    @property
    def budget_type(self):
        return self._budget_type

    @budget_type.setter
    def budget_type(self, value):
        self._budget_type = value
    @property
    def can_repay_flag(self):
        return self._can_repay_flag

    @can_repay_flag.setter
    def can_repay_flag(self, value):
        self._can_repay_flag = value
    @property
    def ext_data(self):
        return self._ext_data

    @ext_data.setter
    def ext_data(self, value):
        self._ext_data = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def loan_ar_no(self):
        return self._loan_ar_no

    @loan_ar_no.setter
    def loan_ar_no(self, value):
        self._loan_ar_no = value
    @property
    def repay_scene(self):
        return self._repay_scene

    @repay_scene.setter
    def repay_scene(self, value):
        self._repay_scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_repay_prin:
            if hasattr(self.apply_repay_prin, 'to_alipay_dict'):
                params['apply_repay_prin'] = self.apply_repay_prin.to_alipay_dict()
            else:
                params['apply_repay_prin'] = self.apply_repay_prin
        if self.budget_type:
            if hasattr(self.budget_type, 'to_alipay_dict'):
                params['budget_type'] = self.budget_type.to_alipay_dict()
            else:
                params['budget_type'] = self.budget_type
        if self.can_repay_flag:
            if hasattr(self.can_repay_flag, 'to_alipay_dict'):
                params['can_repay_flag'] = self.can_repay_flag.to_alipay_dict()
            else:
                params['can_repay_flag'] = self.can_repay_flag
        if self.ext_data:
            if hasattr(self.ext_data, 'to_alipay_dict'):
                params['ext_data'] = self.ext_data.to_alipay_dict()
            else:
                params['ext_data'] = self.ext_data
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.loan_ar_no:
            if hasattr(self.loan_ar_no, 'to_alipay_dict'):
                params['loan_ar_no'] = self.loan_ar_no.to_alipay_dict()
            else:
                params['loan_ar_no'] = self.loan_ar_no
        if self.repay_scene:
            if hasattr(self.repay_scene, 'to_alipay_dict'):
                params['repay_scene'] = self.repay_scene.to_alipay_dict()
            else:
                params['repay_scene'] = self.repay_scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeRepayBudgetQueryModel()
        if 'apply_repay_prin' in d:
            o.apply_repay_prin = d['apply_repay_prin']
        if 'budget_type' in d:
            o.budget_type = d['budget_type']
        if 'can_repay_flag' in d:
            o.can_repay_flag = d['can_repay_flag']
        if 'ext_data' in d:
            o.ext_data = d['ext_data']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'loan_ar_no' in d:
            o.loan_ar_no = d['loan_ar_no']
        if 'repay_scene' in d:
            o.repay_scene = d['repay_scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenPublicPayeeBindCreateModel(object):

    def __init__(self):
        self._login_id = None
        self._pid = None

    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicPayeeBindCreateModel()
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'pid' in d:
            o.pid = d['pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditSupplychainCreditpaySellersignCreateResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSupplychainCreditpaySellersignCreateResponse, self).__init__()
        self._ar_no = None
        self._fail_reason = None
        self._ip_id = None
        self._ip_role_id = None
        self._retry = None
        self._sign_result = None
        self._trace_id = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def fail_reason(self):
        return self._fail_reason

    @fail_reason.setter
    def fail_reason(self, value):
        self._fail_reason = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def sign_result(self):
        return self._sign_result

    @sign_result.setter
    def sign_result(self, value):
        self._sign_result = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSupplychainCreditpaySellersignCreateResponse, self).parse_response_content(response_content)
        if 'ar_no' in response:
            self.ar_no = response['ar_no']
        if 'fail_reason' in response:
            self.fail_reason = response['fail_reason']
        if 'ip_id' in response:
            self.ip_id = response['ip_id']
        if 'ip_role_id' in response:
            self.ip_role_id = response['ip_role_id']
        if 'retry' in response:
            self.retry = response['retry']
        if 'sign_result' in response:
            self.sign_result = response['sign_result']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasRemitFundTransferModel(object):

    def __init__(self):
        self._base_currency = None
        self._bc_remit_id = None
        self._exchange_rate = None
        self._receiver_amount = None
        self._receiver_currency = None
        self._receiver_mid = None
        self._sender_amount = None
        self._sender_currency = None
        self._sender_mid = None

    @property
    def base_currency(self):
        return self._base_currency

    @base_currency.setter
    def base_currency(self, value):
        self._base_currency = value
    @property
    def bc_remit_id(self):
        return self._bc_remit_id

    @bc_remit_id.setter
    def bc_remit_id(self, value):
        self._bc_remit_id = value
    @property
    def exchange_rate(self):
        return self._exchange_rate

    @exchange_rate.setter
    def exchange_rate(self, value):
        self._exchange_rate = value
    @property
    def receiver_amount(self):
        return self._receiver_amount

    @receiver_amount.setter
    def receiver_amount(self, value):
        self._receiver_amount = value
    @property
    def receiver_currency(self):
        return self._receiver_currency

    @receiver_currency.setter
    def receiver_currency(self, value):
        self._receiver_currency = value
    @property
    def receiver_mid(self):
        return self._receiver_mid

    @receiver_mid.setter
    def receiver_mid(self, value):
        self._receiver_mid = value
    @property
    def sender_amount(self):
        return self._sender_amount

    @sender_amount.setter
    def sender_amount(self, value):
        self._sender_amount = value
    @property
    def sender_currency(self):
        return self._sender_currency

    @sender_currency.setter
    def sender_currency(self, value):
        self._sender_currency = value
    @property
    def sender_mid(self):
        return self._sender_mid

    @sender_mid.setter
    def sender_mid(self, value):
        self._sender_mid = value


    def to_alipay_dict(self):
        params = dict()
        if self.base_currency:
            if hasattr(self.base_currency, 'to_alipay_dict'):
                params['base_currency'] = self.base_currency.to_alipay_dict()
            else:
                params['base_currency'] = self.base_currency
        if self.bc_remit_id:
            if hasattr(self.bc_remit_id, 'to_alipay_dict'):
                params['bc_remit_id'] = self.bc_remit_id.to_alipay_dict()
            else:
                params['bc_remit_id'] = self.bc_remit_id
        if self.exchange_rate:
            if hasattr(self.exchange_rate, 'to_alipay_dict'):
                params['exchange_rate'] = self.exchange_rate.to_alipay_dict()
            else:
                params['exchange_rate'] = self.exchange_rate
        if self.receiver_amount:
            if hasattr(self.receiver_amount, 'to_alipay_dict'):
                params['receiver_amount'] = self.receiver_amount.to_alipay_dict()
            else:
                params['receiver_amount'] = self.receiver_amount
        if self.receiver_currency:
            if hasattr(self.receiver_currency, 'to_alipay_dict'):
                params['receiver_currency'] = self.receiver_currency.to_alipay_dict()
            else:
                params['receiver_currency'] = self.receiver_currency
        if self.receiver_mid:
            if hasattr(self.receiver_mid, 'to_alipay_dict'):
                params['receiver_mid'] = self.receiver_mid.to_alipay_dict()
            else:
                params['receiver_mid'] = self.receiver_mid
        if self.sender_amount:
            if hasattr(self.sender_amount, 'to_alipay_dict'):
                params['sender_amount'] = self.sender_amount.to_alipay_dict()
            else:
                params['sender_amount'] = self.sender_amount
        if self.sender_currency:
            if hasattr(self.sender_currency, 'to_alipay_dict'):
                params['sender_currency'] = self.sender_currency.to_alipay_dict()
            else:
                params['sender_currency'] = self.sender_currency
        if self.sender_mid:
            if hasattr(self.sender_mid, 'to_alipay_dict'):
                params['sender_mid'] = self.sender_mid.to_alipay_dict()
            else:
                params['sender_mid'] = self.sender_mid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasRemitFundTransferModel()
        if 'base_currency' in d:
            o.base_currency = d['base_currency']
        if 'bc_remit_id' in d:
            o.bc_remit_id = d['bc_remit_id']
        if 'exchange_rate' in d:
            o.exchange_rate = d['exchange_rate']
        if 'receiver_amount' in d:
            o.receiver_amount = d['receiver_amount']
        if 'receiver_currency' in d:
            o.receiver_currency = d['receiver_currency']
        if 'receiver_mid' in d:
            o.receiver_mid = d['receiver_mid']
        if 'sender_amount' in d:
            o.sender_amount = d['sender_amount']
        if 'sender_currency' in d:
            o.sender_currency = d['sender_currency']
        if 'sender_mid' in d:
            o.sender_mid = d['sender_mid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdCtidInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdCtidInitializeResponse, self).__init__()
        self._random_data = None
        self._stream_number = None

    @property
    def random_data(self):
        return self._random_data

    @random_data.setter
    def random_data(self, value):
        self._random_data = value
    @property
    def stream_number(self):
        return self._stream_number

    @stream_number.setter
    def stream_number(self, value):
        self._stream_number = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdCtidInitializeResponse, self).parse_response_content(response_content)
        if 'random_data' in response:
            self.random_data = response['random_data']
        if 'stream_number' in response:
            self.stream_number = response['stream_number']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsProdCoverage import InsProdCoverage
from alipay.aop.api.domain.InsLiability import InsLiability
from alipay.aop.api.domain.InsMerchant import InsMerchant
from alipay.aop.api.domain.InsProdResource import InsProdResource
from alipay.aop.api.domain.InsProdTag import InsProdTag


class InsProduct(object):

    def __init__(self):
        self._coverages = None
        self._effect_date = None
        self._invalid_date = None
        self._is_sp = None
        self._liabilities = None
        self._merchant = None
        self._prod_code = None
        self._prod_desc = None
        self._prod_name = None
        self._prod_no = None
        self._prod_version = None
        self._real_premium = None
        self._reduce_premium = None
        self._resources = None
        self._sales = None
        self._short_name = None
        self._sp_code = None
        self._tags = None
        self._total_premium = None

    @property
    def coverages(self):
        return self._coverages

    @coverages.setter
    def coverages(self, value):
        if isinstance(value, InsProdCoverage):
            self._coverages = value
        else:
            self._coverages = InsProdCoverage.from_alipay_dict(value)
    @property
    def effect_date(self):
        return self._effect_date

    @effect_date.setter
    def effect_date(self, value):
        self._effect_date = value
    @property
    def invalid_date(self):
        return self._invalid_date

    @invalid_date.setter
    def invalid_date(self, value):
        self._invalid_date = value
    @property
    def is_sp(self):
        return self._is_sp

    @is_sp.setter
    def is_sp(self, value):
        self._is_sp = value
    @property
    def liabilities(self):
        return self._liabilities

    @liabilities.setter
    def liabilities(self, value):
        if isinstance(value, list):
            self._liabilities = list()
            for i in value:
                if isinstance(i, InsLiability):
                    self._liabilities.append(i)
                else:
                    self._liabilities.append(InsLiability.from_alipay_dict(i))
    @property
    def merchant(self):
        return self._merchant

    @merchant.setter
    def merchant(self, value):
        if isinstance(value, InsMerchant):
            self._merchant = value
        else:
            self._merchant = InsMerchant.from_alipay_dict(value)
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value
    @property
    def prod_desc(self):
        return self._prod_desc

    @prod_desc.setter
    def prod_desc(self, value):
        self._prod_desc = value
    @property
    def prod_name(self):
        return self._prod_name

    @prod_name.setter
    def prod_name(self, value):
        self._prod_name = value
    @property
    def prod_no(self):
        return self._prod_no

    @prod_no.setter
    def prod_no(self, value):
        self._prod_no = value
    @property
    def prod_version(self):
        return self._prod_version

    @prod_version.setter
    def prod_version(self, value):
        self._prod_version = value
    @property
    def real_premium(self):
        return self._real_premium

    @real_premium.setter
    def real_premium(self, value):
        self._real_premium = value
    @property
    def reduce_premium(self):
        return self._reduce_premium

    @reduce_premium.setter
    def reduce_premium(self, value):
        self._reduce_premium = value
    @property
    def resources(self):
        return self._resources

    @resources.setter
    def resources(self, value):
        if isinstance(value, list):
            self._resources = list()
            for i in value:
                if isinstance(i, InsProdResource):
                    self._resources.append(i)
                else:
                    self._resources.append(InsProdResource.from_alipay_dict(i))
    @property
    def sales(self):
        return self._sales

    @sales.setter
    def sales(self, value):
        self._sales = value
    @property
    def short_name(self):
        return self._short_name

    @short_name.setter
    def short_name(self, value):
        self._short_name = value
    @property
    def sp_code(self):
        return self._sp_code

    @sp_code.setter
    def sp_code(self, value):
        self._sp_code = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        if isinstance(value, list):
            self._tags = list()
            for i in value:
                if isinstance(i, InsProdTag):
                    self._tags.append(i)
                else:
                    self._tags.append(InsProdTag.from_alipay_dict(i))
    @property
    def total_premium(self):
        return self._total_premium

    @total_premium.setter
    def total_premium(self, value):
        self._total_premium = value


    def to_alipay_dict(self):
        params = dict()
        if self.coverages:
            if hasattr(self.coverages, 'to_alipay_dict'):
                params['coverages'] = self.coverages.to_alipay_dict()
            else:
                params['coverages'] = self.coverages
        if self.effect_date:
            if hasattr(self.effect_date, 'to_alipay_dict'):
                params['effect_date'] = self.effect_date.to_alipay_dict()
            else:
                params['effect_date'] = self.effect_date
        if self.invalid_date:
            if hasattr(self.invalid_date, 'to_alipay_dict'):
                params['invalid_date'] = self.invalid_date.to_alipay_dict()
            else:
                params['invalid_date'] = self.invalid_date
        if self.is_sp:
            if hasattr(self.is_sp, 'to_alipay_dict'):
                params['is_sp'] = self.is_sp.to_alipay_dict()
            else:
                params['is_sp'] = self.is_sp
        if self.liabilities:
            if isinstance(self.liabilities, list):
                for i in range(0, len(self.liabilities)):
                    element = self.liabilities[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.liabilities[i] = element.to_alipay_dict()
            if hasattr(self.liabilities, 'to_alipay_dict'):
                params['liabilities'] = self.liabilities.to_alipay_dict()
            else:
                params['liabilities'] = self.liabilities
        if self.merchant:
            if hasattr(self.merchant, 'to_alipay_dict'):
                params['merchant'] = self.merchant.to_alipay_dict()
            else:
                params['merchant'] = self.merchant
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        if self.prod_desc:
            if hasattr(self.prod_desc, 'to_alipay_dict'):
                params['prod_desc'] = self.prod_desc.to_alipay_dict()
            else:
                params['prod_desc'] = self.prod_desc
        if self.prod_name:
            if hasattr(self.prod_name, 'to_alipay_dict'):
                params['prod_name'] = self.prod_name.to_alipay_dict()
            else:
                params['prod_name'] = self.prod_name
        if self.prod_no:
            if hasattr(self.prod_no, 'to_alipay_dict'):
                params['prod_no'] = self.prod_no.to_alipay_dict()
            else:
                params['prod_no'] = self.prod_no
        if self.prod_version:
            if hasattr(self.prod_version, 'to_alipay_dict'):
                params['prod_version'] = self.prod_version.to_alipay_dict()
            else:
                params['prod_version'] = self.prod_version
        if self.real_premium:
            if hasattr(self.real_premium, 'to_alipay_dict'):
                params['real_premium'] = self.real_premium.to_alipay_dict()
            else:
                params['real_premium'] = self.real_premium
        if self.reduce_premium:
            if hasattr(self.reduce_premium, 'to_alipay_dict'):
                params['reduce_premium'] = self.reduce_premium.to_alipay_dict()
            else:
                params['reduce_premium'] = self.reduce_premium
        if self.resources:
            if isinstance(self.resources, list):
                for i in range(0, len(self.resources)):
                    element = self.resources[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.resources[i] = element.to_alipay_dict()
            if hasattr(self.resources, 'to_alipay_dict'):
                params['resources'] = self.resources.to_alipay_dict()
            else:
                params['resources'] = self.resources
        if self.sales:
            if hasattr(self.sales, 'to_alipay_dict'):
                params['sales'] = self.sales.to_alipay_dict()
            else:
                params['sales'] = self.sales
        if self.short_name:
            if hasattr(self.short_name, 'to_alipay_dict'):
                params['short_name'] = self.short_name.to_alipay_dict()
            else:
                params['short_name'] = self.short_name
        if self.sp_code:
            if hasattr(self.sp_code, 'to_alipay_dict'):
                params['sp_code'] = self.sp_code.to_alipay_dict()
            else:
                params['sp_code'] = self.sp_code
        if self.tags:
            if isinstance(self.tags, list):
                for i in range(0, len(self.tags)):
                    element = self.tags[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tags[i] = element.to_alipay_dict()
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.total_premium:
            if hasattr(self.total_premium, 'to_alipay_dict'):
                params['total_premium'] = self.total_premium.to_alipay_dict()
            else:
                params['total_premium'] = self.total_premium
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsProduct()
        if 'coverages' in d:
            o.coverages = d['coverages']
        if 'effect_date' in d:
            o.effect_date = d['effect_date']
        if 'invalid_date' in d:
            o.invalid_date = d['invalid_date']
        if 'is_sp' in d:
            o.is_sp = d['is_sp']
        if 'liabilities' in d:
            o.liabilities = d['liabilities']
        if 'merchant' in d:
            o.merchant = d['merchant']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        if 'prod_desc' in d:
            o.prod_desc = d['prod_desc']
        if 'prod_name' in d:
            o.prod_name = d['prod_name']
        if 'prod_no' in d:
            o.prod_no = d['prod_no']
        if 'prod_version' in d:
            o.prod_version = d['prod_version']
        if 'real_premium' in d:
            o.real_premium = d['real_premium']
        if 'reduce_premium' in d:
            o.reduce_premium = d['reduce_premium']
        if 'resources' in d:
            o.resources = d['resources']
        if 'sales' in d:
            o.sales = d['sales']
        if 'short_name' in d:
            o.short_name = d['short_name']
        if 'sp_code' in d:
            o.sp_code = d['sp_code']
        if 'tags' in d:
            o.tags = d['tags']
        if 'total_premium' in d:
            o.total_premium = d['total_premium']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RequestExtShopItemQuery(object):

    def __init__(self):
        self._brand_code = None
        self._category_code = None
        self._description = None
        self._item_code = None
        self._kb_shop_id = None
        self._price = None
        self._title = None

    @property
    def brand_code(self):
        return self._brand_code

    @brand_code.setter
    def brand_code(self, value):
        self._brand_code = value
    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def kb_shop_id(self):
        return self._kb_shop_id

    @kb_shop_id.setter
    def kb_shop_id(self, value):
        self._kb_shop_id = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_code:
            if hasattr(self.brand_code, 'to_alipay_dict'):
                params['brand_code'] = self.brand_code.to_alipay_dict()
            else:
                params['brand_code'] = self.brand_code
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.kb_shop_id:
            if hasattr(self.kb_shop_id, 'to_alipay_dict'):
                params['kb_shop_id'] = self.kb_shop_id.to_alipay_dict()
            else:
                params['kb_shop_id'] = self.kb_shop_id
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RequestExtShopItemQuery()
        if 'brand_code' in d:
            o.brand_code = d['brand_code']
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'description' in d:
            o.description = d['description']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'kb_shop_id' in d:
            o.kb_shop_id = d['kb_shop_id']
        if 'price' in d:
            o.price = d['price']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenBpaasServiceBindModel(object):

    def __init__(self):
        self._bpaas_app_id = None
        self._bpaas_app_version = None
        self._service_code = None
        self._service_version = None

    @property
    def bpaas_app_id(self):
        return self._bpaas_app_id

    @bpaas_app_id.setter
    def bpaas_app_id(self, value):
        self._bpaas_app_id = value
    @property
    def bpaas_app_version(self):
        return self._bpaas_app_version

    @bpaas_app_version.setter
    def bpaas_app_version(self, value):
        self._bpaas_app_version = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_version(self):
        return self._service_version

    @service_version.setter
    def service_version(self, value):
        self._service_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.bpaas_app_id:
            if hasattr(self.bpaas_app_id, 'to_alipay_dict'):
                params['bpaas_app_id'] = self.bpaas_app_id.to_alipay_dict()
            else:
                params['bpaas_app_id'] = self.bpaas_app_id
        if self.bpaas_app_version:
            if hasattr(self.bpaas_app_version, 'to_alipay_dict'):
                params['bpaas_app_version'] = self.bpaas_app_version.to_alipay_dict()
            else:
                params['bpaas_app_version'] = self.bpaas_app_version
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_version:
            if hasattr(self.service_version, 'to_alipay_dict'):
                params['service_version'] = self.service_version.to_alipay_dict()
            else:
                params['service_version'] = self.service_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenBpaasServiceBindModel()
        if 'bpaas_app_id' in d:
            o.bpaas_app_id = d['bpaas_app_id']
        if 'bpaas_app_version' in d:
            o.bpaas_app_version = d['bpaas_app_version']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_version' in d:
            o.service_version = d['service_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsState(object):

    def __init__(self):
        self._algorithm_goods_id = None
        self._floor = None
        self._left_loc = None

    @property
    def algorithm_goods_id(self):
        return self._algorithm_goods_id

    @algorithm_goods_id.setter
    def algorithm_goods_id(self, value):
        self._algorithm_goods_id = value
    @property
    def floor(self):
        return self._floor

    @floor.setter
    def floor(self, value):
        self._floor = value
    @property
    def left_loc(self):
        return self._left_loc

    @left_loc.setter
    def left_loc(self, value):
        self._left_loc = value


    def to_alipay_dict(self):
        params = dict()
        if self.algorithm_goods_id:
            if hasattr(self.algorithm_goods_id, 'to_alipay_dict'):
                params['algorithm_goods_id'] = self.algorithm_goods_id.to_alipay_dict()
            else:
                params['algorithm_goods_id'] = self.algorithm_goods_id
        if self.floor:
            if hasattr(self.floor, 'to_alipay_dict'):
                params['floor'] = self.floor.to_alipay_dict()
            else:
                params['floor'] = self.floor
        if self.left_loc:
            if hasattr(self.left_loc, 'to_alipay_dict'):
                params['left_loc'] = self.left_loc.to_alipay_dict()
            else:
                params['left_loc'] = self.left_loc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsState()
        if 'algorithm_goods_id' in d:
            o.algorithm_goods_id = d['algorithm_goods_id']
        if 'floor' in d:
            o.floor = d['floor']
        if 'left_loc' in d:
            o.left_loc = d['left_loc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AdvanceElementsDTO(object):

    def __init__(self):
        self._advance_account_no = None
        self._advance_account_type = None
        self._advance_user_id = None
        self._auto_advance = None

    @property
    def advance_account_no(self):
        return self._advance_account_no

    @advance_account_no.setter
    def advance_account_no(self, value):
        self._advance_account_no = value
    @property
    def advance_account_type(self):
        return self._advance_account_type

    @advance_account_type.setter
    def advance_account_type(self, value):
        self._advance_account_type = value
    @property
    def advance_user_id(self):
        return self._advance_user_id

    @advance_user_id.setter
    def advance_user_id(self, value):
        self._advance_user_id = value
    @property
    def auto_advance(self):
        return self._auto_advance

    @auto_advance.setter
    def auto_advance(self, value):
        self._auto_advance = value


    def to_alipay_dict(self):
        params = dict()
        if self.advance_account_no:
            if hasattr(self.advance_account_no, 'to_alipay_dict'):
                params['advance_account_no'] = self.advance_account_no.to_alipay_dict()
            else:
                params['advance_account_no'] = self.advance_account_no
        if self.advance_account_type:
            if hasattr(self.advance_account_type, 'to_alipay_dict'):
                params['advance_account_type'] = self.advance_account_type.to_alipay_dict()
            else:
                params['advance_account_type'] = self.advance_account_type
        if self.advance_user_id:
            if hasattr(self.advance_user_id, 'to_alipay_dict'):
                params['advance_user_id'] = self.advance_user_id.to_alipay_dict()
            else:
                params['advance_user_id'] = self.advance_user_id
        if self.auto_advance:
            if hasattr(self.auto_advance, 'to_alipay_dict'):
                params['auto_advance'] = self.auto_advance.to_alipay_dict()
            else:
                params['auto_advance'] = self.auto_advance
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AdvanceElementsDTO()
        if 'advance_account_no' in d:
            o.advance_account_no = d['advance_account_no']
        if 'advance_account_type' in d:
            o.advance_account_type = d['advance_account_type']
        if 'advance_user_id' in d:
            o.advance_user_id = d['advance_user_id']
        if 'auto_advance' in d:
            o.auto_advance = d['auto_advance']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ConsumerNotifyIstd(object):

    def __init__(self):
        self._goods_count = None
        self._goods_img = None
        self._goods_name = None
        self._merchant_mobile = None
        self._merchant_name = None
        self._tiny_app_id = None
        self._tiny_app_url = None

    @property
    def goods_count(self):
        return self._goods_count

    @goods_count.setter
    def goods_count(self, value):
        self._goods_count = value
    @property
    def goods_img(self):
        return self._goods_img

    @goods_img.setter
    def goods_img(self, value):
        self._goods_img = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def merchant_mobile(self):
        return self._merchant_mobile

    @merchant_mobile.setter
    def merchant_mobile(self, value):
        self._merchant_mobile = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def tiny_app_id(self):
        return self._tiny_app_id

    @tiny_app_id.setter
    def tiny_app_id(self, value):
        self._tiny_app_id = value
    @property
    def tiny_app_url(self):
        return self._tiny_app_url

    @tiny_app_url.setter
    def tiny_app_url(self, value):
        self._tiny_app_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_count:
            if hasattr(self.goods_count, 'to_alipay_dict'):
                params['goods_count'] = self.goods_count.to_alipay_dict()
            else:
                params['goods_count'] = self.goods_count
        if self.goods_img:
            if hasattr(self.goods_img, 'to_alipay_dict'):
                params['goods_img'] = self.goods_img.to_alipay_dict()
            else:
                params['goods_img'] = self.goods_img
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.merchant_mobile:
            if hasattr(self.merchant_mobile, 'to_alipay_dict'):
                params['merchant_mobile'] = self.merchant_mobile.to_alipay_dict()
            else:
                params['merchant_mobile'] = self.merchant_mobile
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.tiny_app_id:
            if hasattr(self.tiny_app_id, 'to_alipay_dict'):
                params['tiny_app_id'] = self.tiny_app_id.to_alipay_dict()
            else:
                params['tiny_app_id'] = self.tiny_app_id
        if self.tiny_app_url:
            if hasattr(self.tiny_app_url, 'to_alipay_dict'):
                params['tiny_app_url'] = self.tiny_app_url.to_alipay_dict()
            else:
                params['tiny_app_url'] = self.tiny_app_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ConsumerNotifyIstd()
        if 'goods_count' in d:
            o.goods_count = d['goods_count']
        if 'goods_img' in d:
            o.goods_img = d['goods_img']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'merchant_mobile' in d:
            o.merchant_mobile = d['merchant_mobile']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'tiny_app_id' in d:
            o.tiny_app_id = d['tiny_app_id']
        if 'tiny_app_url' in d:
            o.tiny_app_url = d['tiny_app_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeRepaybillOrderCloseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeRepaybillOrderCloseResponse, self).__init__()
        self._bill_no = None
        self._paid_amount = None
        self._repay_fund_order_no = None
        self._repay_order_status = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def paid_amount(self):
        return self._paid_amount

    @paid_amount.setter
    def paid_amount(self, value):
        self._paid_amount = value
    @property
    def repay_fund_order_no(self):
        return self._repay_fund_order_no

    @repay_fund_order_no.setter
    def repay_fund_order_no(self, value):
        self._repay_fund_order_no = value
    @property
    def repay_order_status(self):
        return self._repay_order_status

    @repay_order_status.setter
    def repay_order_status(self, value):
        self._repay_order_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeRepaybillOrderCloseResponse, self).parse_response_content(response_content)
        if 'bill_no' in response:
            self.bill_no = response['bill_no']
        if 'paid_amount' in response:
            self.paid_amount = response['paid_amount']
        if 'repay_fund_order_no' in response:
            self.repay_fund_order_no = response['repay_fund_order_no']
        if 'repay_order_status' in response:
            self.repay_order_status = response['repay_order_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceSportsVunueOrdervoucherVerifyModel(object):

    def __init__(self):
        self._desc = None
        self._order_id = None
        self._out_order_id = None
        self._out_voucher_id = None
        self._verify_count = None
        self._verify_status = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def out_voucher_id(self):
        return self._out_voucher_id

    @out_voucher_id.setter
    def out_voucher_id(self, value):
        self._out_voucher_id = value
    @property
    def verify_count(self):
        return self._verify_count

    @verify_count.setter
    def verify_count(self, value):
        self._verify_count = value
    @property
    def verify_status(self):
        return self._verify_status

    @verify_status.setter
    def verify_status(self, value):
        self._verify_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.out_voucher_id:
            if hasattr(self.out_voucher_id, 'to_alipay_dict'):
                params['out_voucher_id'] = self.out_voucher_id.to_alipay_dict()
            else:
                params['out_voucher_id'] = self.out_voucher_id
        if self.verify_count:
            if hasattr(self.verify_count, 'to_alipay_dict'):
                params['verify_count'] = self.verify_count.to_alipay_dict()
            else:
                params['verify_count'] = self.verify_count
        if self.verify_status:
            if hasattr(self.verify_status, 'to_alipay_dict'):
                params['verify_status'] = self.verify_status.to_alipay_dict()
            else:
                params['verify_status'] = self.verify_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceSportsVunueOrdervoucherVerifyModel()
        if 'desc' in d:
            o.desc = d['desc']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'out_voucher_id' in d:
            o.out_voucher_id = d['out_voucher_id']
        if 'verify_count' in d:
            o.verify_count = d['verify_count']
        if 'verify_status' in d:
            o.verify_status = d['verify_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MemberCardRefundDetail(object):

    def __init__(self):
        self._balance = None
        self._order_id = None
        self._principal_balance = None
        self._record_time = None
        self._refund_amount = None
        self._refund_benefit_amount = None
        self._subtract_benefit_amount = None
        self._subtract_discount_amount = None
        self._subtract_voucher_amount = None

    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def principal_balance(self):
        return self._principal_balance

    @principal_balance.setter
    def principal_balance(self, value):
        self._principal_balance = value
    @property
    def record_time(self):
        return self._record_time

    @record_time.setter
    def record_time(self, value):
        self._record_time = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_benefit_amount(self):
        return self._refund_benefit_amount

    @refund_benefit_amount.setter
    def refund_benefit_amount(self, value):
        self._refund_benefit_amount = value
    @property
    def subtract_benefit_amount(self):
        return self._subtract_benefit_amount

    @subtract_benefit_amount.setter
    def subtract_benefit_amount(self, value):
        self._subtract_benefit_amount = value
    @property
    def subtract_discount_amount(self):
        return self._subtract_discount_amount

    @subtract_discount_amount.setter
    def subtract_discount_amount(self, value):
        self._subtract_discount_amount = value
    @property
    def subtract_voucher_amount(self):
        return self._subtract_voucher_amount

    @subtract_voucher_amount.setter
    def subtract_voucher_amount(self, value):
        self._subtract_voucher_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.principal_balance:
            if hasattr(self.principal_balance, 'to_alipay_dict'):
                params['principal_balance'] = self.principal_balance.to_alipay_dict()
            else:
                params['principal_balance'] = self.principal_balance
        if self.record_time:
            if hasattr(self.record_time, 'to_alipay_dict'):
                params['record_time'] = self.record_time.to_alipay_dict()
            else:
                params['record_time'] = self.record_time
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.refund_benefit_amount:
            if hasattr(self.refund_benefit_amount, 'to_alipay_dict'):
                params['refund_benefit_amount'] = self.refund_benefit_amount.to_alipay_dict()
            else:
                params['refund_benefit_amount'] = self.refund_benefit_amount
        if self.subtract_benefit_amount:
            if hasattr(self.subtract_benefit_amount, 'to_alipay_dict'):
                params['subtract_benefit_amount'] = self.subtract_benefit_amount.to_alipay_dict()
            else:
                params['subtract_benefit_amount'] = self.subtract_benefit_amount
        if self.subtract_discount_amount:
            if hasattr(self.subtract_discount_amount, 'to_alipay_dict'):
                params['subtract_discount_amount'] = self.subtract_discount_amount.to_alipay_dict()
            else:
                params['subtract_discount_amount'] = self.subtract_discount_amount
        if self.subtract_voucher_amount:
            if hasattr(self.subtract_voucher_amount, 'to_alipay_dict'):
                params['subtract_voucher_amount'] = self.subtract_voucher_amount.to_alipay_dict()
            else:
                params['subtract_voucher_amount'] = self.subtract_voucher_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MemberCardRefundDetail()
        if 'balance' in d:
            o.balance = d['balance']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'principal_balance' in d:
            o.principal_balance = d['principal_balance']
        if 'record_time' in d:
            o.record_time = d['record_time']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'refund_benefit_amount' in d:
            o.refund_benefit_amount = d['refund_benefit_amount']
        if 'subtract_benefit_amount' in d:
            o.subtract_benefit_amount = d['subtract_benefit_amount']
        if 'subtract_discount_amount' in d:
            o.subtract_discount_amount = d['subtract_discount_amount']
        if 'subtract_voucher_amount' in d:
            o.subtract_voucher_amount = d['subtract_voucher_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainDefinAssetmanagePenetrateQueryModel(object):

    def __init__(self):
        self._biz_params = None
        self._function = None
        self._request_id = None

    @property
    def biz_params(self):
        return self._biz_params

    @biz_params.setter
    def biz_params(self, value):
        self._biz_params = value
    @property
    def function(self):
        return self._function

    @function.setter
    def function(self, value):
        self._function = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_params:
            if hasattr(self.biz_params, 'to_alipay_dict'):
                params['biz_params'] = self.biz_params.to_alipay_dict()
            else:
                params['biz_params'] = self.biz_params
        if self.function:
            if hasattr(self.function, 'to_alipay_dict'):
                params['function'] = self.function.to_alipay_dict()
            else:
                params['function'] = self.function
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainDefinAssetmanagePenetrateQueryModel()
        if 'biz_params' in d:
            o.biz_params = d['biz_params']
        if 'function' in d:
            o.function = d['function']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PaymentGoods(object):

    def __init__(self):
        self._brand = None
        self._category = None
        self._quantity = None
        self._remark = None
        self._title = None
        self._unit_amount = None
        self._unit_currency = None

    @property
    def brand(self):
        return self._brand

    @brand.setter
    def brand(self, value):
        self._brand = value
    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def unit_amount(self):
        return self._unit_amount

    @unit_amount.setter
    def unit_amount(self, value):
        self._unit_amount = value
    @property
    def unit_currency(self):
        return self._unit_currency

    @unit_currency.setter
    def unit_currency(self, value):
        self._unit_currency = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand:
            if hasattr(self.brand, 'to_alipay_dict'):
                params['brand'] = self.brand.to_alipay_dict()
            else:
                params['brand'] = self.brand
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.unit_amount:
            if hasattr(self.unit_amount, 'to_alipay_dict'):
                params['unit_amount'] = self.unit_amount.to_alipay_dict()
            else:
                params['unit_amount'] = self.unit_amount
        if self.unit_currency:
            if hasattr(self.unit_currency, 'to_alipay_dict'):
                params['unit_currency'] = self.unit_currency.to_alipay_dict()
            else:
                params['unit_currency'] = self.unit_currency
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentGoods()
        if 'brand' in d:
            o.brand = d['brand']
        if 'category' in d:
            o.category = d['category']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'remark' in d:
            o.remark = d['remark']
        if 'title' in d:
            o.title = d['title']
        if 'unit_amount' in d:
            o.unit_amount = d['unit_amount']
        if 'unit_currency' in d:
            o.unit_currency = d['unit_currency']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandIndirectZftUpgradeModel(object):

    def __init__(self):
        self._additional_cert_image = None
        self._additional_cert_no = None
        self._additional_cert_type = None
        self._smid = None

    @property
    def additional_cert_image(self):
        return self._additional_cert_image

    @additional_cert_image.setter
    def additional_cert_image(self, value):
        self._additional_cert_image = value
    @property
    def additional_cert_no(self):
        return self._additional_cert_no

    @additional_cert_no.setter
    def additional_cert_no(self, value):
        self._additional_cert_no = value
    @property
    def additional_cert_type(self):
        return self._additional_cert_type

    @additional_cert_type.setter
    def additional_cert_type(self, value):
        self._additional_cert_type = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.additional_cert_image:
            if hasattr(self.additional_cert_image, 'to_alipay_dict'):
                params['additional_cert_image'] = self.additional_cert_image.to_alipay_dict()
            else:
                params['additional_cert_image'] = self.additional_cert_image
        if self.additional_cert_no:
            if hasattr(self.additional_cert_no, 'to_alipay_dict'):
                params['additional_cert_no'] = self.additional_cert_no.to_alipay_dict()
            else:
                params['additional_cert_no'] = self.additional_cert_no
        if self.additional_cert_type:
            if hasattr(self.additional_cert_type, 'to_alipay_dict'):
                params['additional_cert_type'] = self.additional_cert_type.to_alipay_dict()
            else:
                params['additional_cert_type'] = self.additional_cert_type
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIndirectZftUpgradeModel()
        if 'additional_cert_image' in d:
            o.additional_cert_image = d['additional_cert_image']
        if 'additional_cert_no' in d:
            o.additional_cert_no = d['additional_cert_no']
        if 'additional_cert_type' in d:
            o.additional_cert_type = d['additional_cert_type']
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SsdataDataserviceRiskAudioVerifyModel(object):

    def __init__(self):
        self._audio_content = None
        self._audio_type = None
        self._checker = None
        self._risk_type = None
        self._sample_rate = None

    @property
    def audio_content(self):
        return self._audio_content

    @audio_content.setter
    def audio_content(self, value):
        self._audio_content = value
    @property
    def audio_type(self):
        return self._audio_type

    @audio_type.setter
    def audio_type(self, value):
        self._audio_type = value
    @property
    def checker(self):
        return self._checker

    @checker.setter
    def checker(self, value):
        self._checker = value
    @property
    def risk_type(self):
        return self._risk_type

    @risk_type.setter
    def risk_type(self, value):
        if isinstance(value, list):
            self._risk_type = list()
            for i in value:
                self._risk_type.append(i)
    @property
    def sample_rate(self):
        return self._sample_rate

    @sample_rate.setter
    def sample_rate(self, value):
        self._sample_rate = value


    def to_alipay_dict(self):
        params = dict()
        if self.audio_content:
            if hasattr(self.audio_content, 'to_alipay_dict'):
                params['audio_content'] = self.audio_content.to_alipay_dict()
            else:
                params['audio_content'] = self.audio_content
        if self.audio_type:
            if hasattr(self.audio_type, 'to_alipay_dict'):
                params['audio_type'] = self.audio_type.to_alipay_dict()
            else:
                params['audio_type'] = self.audio_type
        if self.checker:
            if hasattr(self.checker, 'to_alipay_dict'):
                params['checker'] = self.checker.to_alipay_dict()
            else:
                params['checker'] = self.checker
        if self.risk_type:
            if isinstance(self.risk_type, list):
                for i in range(0, len(self.risk_type)):
                    element = self.risk_type[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.risk_type[i] = element.to_alipay_dict()
            if hasattr(self.risk_type, 'to_alipay_dict'):
                params['risk_type'] = self.risk_type.to_alipay_dict()
            else:
                params['risk_type'] = self.risk_type
        if self.sample_rate:
            if hasattr(self.sample_rate, 'to_alipay_dict'):
                params['sample_rate'] = self.sample_rate.to_alipay_dict()
            else:
                params['sample_rate'] = self.sample_rate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SsdataDataserviceRiskAudioVerifyModel()
        if 'audio_content' in d:
            o.audio_content = d['audio_content']
        if 'audio_type' in d:
            o.audio_type = d['audio_type']
        if 'checker' in d:
            o.checker = d['checker']
        if 'risk_type' in d:
            o.risk_type = d['risk_type']
        if 'sample_rate' in d:
            o.sample_rate = d['sample_rate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SiteInfoKt(object):

    def __init__(self):
        self._account = None
        self._password = None
        self._site_name = None
        self._site_type = None
        self._site_url = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def password(self):
        return self._password

    @password.setter
    def password(self, value):
        self._password = value
    @property
    def site_name(self):
        return self._site_name

    @site_name.setter
    def site_name(self, value):
        self._site_name = value
    @property
    def site_type(self):
        return self._site_type

    @site_type.setter
    def site_type(self, value):
        self._site_type = value
    @property
    def site_url(self):
        return self._site_url

    @site_url.setter
    def site_url(self, value):
        self._site_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.password:
            if hasattr(self.password, 'to_alipay_dict'):
                params['password'] = self.password.to_alipay_dict()
            else:
                params['password'] = self.password
        if self.site_name:
            if hasattr(self.site_name, 'to_alipay_dict'):
                params['site_name'] = self.site_name.to_alipay_dict()
            else:
                params['site_name'] = self.site_name
        if self.site_type:
            if hasattr(self.site_type, 'to_alipay_dict'):
                params['site_type'] = self.site_type.to_alipay_dict()
            else:
                params['site_type'] = self.site_type
        if self.site_url:
            if hasattr(self.site_url, 'to_alipay_dict'):
                params['site_url'] = self.site_url.to_alipay_dict()
            else:
                params['site_url'] = self.site_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SiteInfoKt()
        if 'account' in d:
            o.account = d['account']
        if 'password' in d:
            o.password = d['password']
        if 'site_name' in d:
            o.site_name = d['site_name']
        if 'site_type' in d:
            o.site_type = d['site_type']
        if 'site_url' in d:
            o.site_url = d['site_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignCashListQueryModel(object):

    def __init__(self):
        self._camp_status = None
        self._page_index = None
        self._page_size = None

    @property
    def camp_status(self):
        return self._camp_status

    @camp_status.setter
    def camp_status(self, value):
        self._camp_status = value
    @property
    def page_index(self):
        return self._page_index

    @page_index.setter
    def page_index(self, value):
        self._page_index = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.camp_status:
            if hasattr(self.camp_status, 'to_alipay_dict'):
                params['camp_status'] = self.camp_status.to_alipay_dict()
            else:
                params['camp_status'] = self.camp_status
        if self.page_index:
            if hasattr(self.page_index, 'to_alipay_dict'):
                params['page_index'] = self.page_index.to_alipay_dict()
            else:
                params['page_index'] = self.page_index
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignCashListQueryModel()
        if 'camp_status' in d:
            o.camp_status = d['camp_status']
        if 'page_index' in d:
            o.page_index = d['page_index']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ModelMeta(object):

    def __init__(self):
        self._model_desc = None
        self._model_name = None
        self._model_uk = None
        self._query_key = None

    @property
    def model_desc(self):
        return self._model_desc

    @model_desc.setter
    def model_desc(self, value):
        self._model_desc = value
    @property
    def model_name(self):
        return self._model_name

    @model_name.setter
    def model_name(self, value):
        self._model_name = value
    @property
    def model_uk(self):
        return self._model_uk

    @model_uk.setter
    def model_uk(self, value):
        self._model_uk = value
    @property
    def query_key(self):
        return self._query_key

    @query_key.setter
    def query_key(self, value):
        if isinstance(value, list):
            self._query_key = list()
            for i in value:
                self._query_key.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.model_desc:
            if hasattr(self.model_desc, 'to_alipay_dict'):
                params['model_desc'] = self.model_desc.to_alipay_dict()
            else:
                params['model_desc'] = self.model_desc
        if self.model_name:
            if hasattr(self.model_name, 'to_alipay_dict'):
                params['model_name'] = self.model_name.to_alipay_dict()
            else:
                params['model_name'] = self.model_name
        if self.model_uk:
            if hasattr(self.model_uk, 'to_alipay_dict'):
                params['model_uk'] = self.model_uk.to_alipay_dict()
            else:
                params['model_uk'] = self.model_uk
        if self.query_key:
            if isinstance(self.query_key, list):
                for i in range(0, len(self.query_key)):
                    element = self.query_key[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.query_key[i] = element.to_alipay_dict()
            if hasattr(self.query_key, 'to_alipay_dict'):
                params['query_key'] = self.query_key.to_alipay_dict()
            else:
                params['query_key'] = self.query_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ModelMeta()
        if 'model_desc' in d:
            o.model_desc = d['model_desc']
        if 'model_name' in d:
            o.model_name = d['model_name']
        if 'model_uk' in d:
            o.model_uk = d['model_uk']
        if 'query_key' in d:
            o.query_key = d['query_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DataSyncPayload(object):

    def __init__(self):
        self._biz_data = None
        self._device_id = None
        self._scene = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DataSyncPayload()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserJobcardInfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserJobcardInfoQueryResponse, self).__init__()
        self._admin_area = None
        self._gender = None
        self._intent_post_tag = None
        self._job_site_type = None
        self._job_time_type = None
        self._local_range = None
        self._skill_tag = None
        self._suitable_age_status = None
        self._user_age = None
        self._user_name = None
        self._user_phone = None

    @property
    def admin_area(self):
        return self._admin_area

    @admin_area.setter
    def admin_area(self, value):
        self._admin_area = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def intent_post_tag(self):
        return self._intent_post_tag

    @intent_post_tag.setter
    def intent_post_tag(self, value):
        self._intent_post_tag = value
    @property
    def job_site_type(self):
        return self._job_site_type

    @job_site_type.setter
    def job_site_type(self, value):
        self._job_site_type = value
    @property
    def job_time_type(self):
        return self._job_time_type

    @job_time_type.setter
    def job_time_type(self, value):
        self._job_time_type = value
    @property
    def local_range(self):
        return self._local_range

    @local_range.setter
    def local_range(self, value):
        self._local_range = value
    @property
    def skill_tag(self):
        return self._skill_tag

    @skill_tag.setter
    def skill_tag(self, value):
        self._skill_tag = value
    @property
    def suitable_age_status(self):
        return self._suitable_age_status

    @suitable_age_status.setter
    def suitable_age_status(self, value):
        self._suitable_age_status = value
    @property
    def user_age(self):
        return self._user_age

    @user_age.setter
    def user_age(self, value):
        self._user_age = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value
    @property
    def user_phone(self):
        return self._user_phone

    @user_phone.setter
    def user_phone(self, value):
        self._user_phone = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserJobcardInfoQueryResponse, self).parse_response_content(response_content)
        if 'admin_area' in response:
            self.admin_area = response['admin_area']
        if 'gender' in response:
            self.gender = response['gender']
        if 'intent_post_tag' in response:
            self.intent_post_tag = response['intent_post_tag']
        if 'job_site_type' in response:
            self.job_site_type = response['job_site_type']
        if 'job_time_type' in response:
            self.job_time_type = response['job_time_type']
        if 'local_range' in response:
            self.local_range = response['local_range']
        if 'skill_tag' in response:
            self.skill_tag = response['skill_tag']
        if 'suitable_age_status' in response:
            self.suitable_age_status = response['suitable_age_status']
        if 'user_age' in response:
            self.user_age = response['user_age']
        if 'user_name' in response:
            self.user_name = response['user_name']
        if 'user_phone' in response:
            self.user_phone = response['user_phone']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiCateringOrderInfoCancelResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringOrderInfoCancelResponse, self).__init__()
        self._retry = None

    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringOrderInfoCancelResponse, self).parse_response_content(response_content)
        if 'retry' in response:
            self.retry = response['retry']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPeUserOrderConsultModel(object):

    def __init__(self):
        self._apply_amount = None
        self._buyer_id = None
        self._category_code = None
        self._credit_scene = None
        self._ext_params = None
        self._out_order_no = None
        self._product_code = None
        self._risk_info = None
        self._seller_id = None

    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        self._apply_amount = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def credit_scene(self):
        return self._credit_scene

    @credit_scene.setter
    def credit_scene(self, value):
        self._credit_scene = value
    @property
    def ext_params(self):
        return self._ext_params

    @ext_params.setter
    def ext_params(self, value):
        self._ext_params = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def risk_info(self):
        return self._risk_info

    @risk_info.setter
    def risk_info(self, value):
        self._risk_info = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.credit_scene:
            if hasattr(self.credit_scene, 'to_alipay_dict'):
                params['credit_scene'] = self.credit_scene.to_alipay_dict()
            else:
                params['credit_scene'] = self.credit_scene
        if self.ext_params:
            if hasattr(self.ext_params, 'to_alipay_dict'):
                params['ext_params'] = self.ext_params.to_alipay_dict()
            else:
                params['ext_params'] = self.ext_params
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.risk_info:
            if hasattr(self.risk_info, 'to_alipay_dict'):
                params['risk_info'] = self.risk_info.to_alipay_dict()
            else:
                params['risk_info'] = self.risk_info
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeUserOrderConsultModel()
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'credit_scene' in d:
            o.credit_scene = d['credit_scene']
        if 'ext_params' in d:
            o.ext_params = d['ext_params']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'risk_info' in d:
            o.risk_info = d['risk_info']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechOceanbasePassinfoLogininfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechOceanbasePassinfoLogininfoQueryResponse, self).__init__()
        self._entity_id = None
        self._passport_id = None
        self._role_type = None

    @property
    def entity_id(self):
        return self._entity_id

    @entity_id.setter
    def entity_id(self, value):
        self._entity_id = value
    @property
    def passport_id(self):
        return self._passport_id

    @passport_id.setter
    def passport_id(self, value):
        self._passport_id = value
    @property
    def role_type(self):
        return self._role_type

    @role_type.setter
    def role_type(self, value):
        self._role_type = value

    def parse_response_content(self, response_content):
        response = super(AnttechOceanbasePassinfoLogininfoQueryResponse, self).parse_response_content(response_content)
        if 'entity_id' in response:
            self.entity_id = response['entity_id']
        if 'passport_id' in response:
            self.passport_id = response['passport_id']
        if 'role_type' in response:
            self.role_type = response['role_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CertInfoResponse(object):

    def __init__(self):
        self._cert_name = None
        self._cert_number = None
        self._cert_type = None
        self._uid = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_number(self):
        return self._cert_number

    @cert_number.setter
    def cert_number(self, value):
        self._cert_number = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        if isinstance(value, list):
            self._uid = list()
            for i in value:
                self._uid.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_number:
            if hasattr(self.cert_number, 'to_alipay_dict'):
                params['cert_number'] = self.cert_number.to_alipay_dict()
            else:
                params['cert_number'] = self.cert_number
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.uid:
            if isinstance(self.uid, list):
                for i in range(0, len(self.uid)):
                    element = self.uid[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.uid[i] = element.to_alipay_dict()
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CertInfoResponse()
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_number' in d:
            o.cert_number = d['cert_number']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniSafedomainDeleteModel(object):

    def __init__(self):
        self._safe_domain = None

    @property
    def safe_domain(self):
        return self._safe_domain

    @safe_domain.setter
    def safe_domain(self, value):
        self._safe_domain = value


    def to_alipay_dict(self):
        params = dict()
        if self.safe_domain:
            if hasattr(self.safe_domain, 'to_alipay_dict'):
                params['safe_domain'] = self.safe_domain.to_alipay_dict()
            else:
                params['safe_domain'] = self.safe_domain
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniSafedomainDeleteModel()
        if 'safe_domain' in d:
            o.safe_domain = d['safe_domain']
        return o


